#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#------------------------------------------------------------------------------------------------- 

import sys
import logging
from os.path import normpath, realpath, join
from xpyv import project_root_path
from xiv_xsf.console import print_in_color

from hostattachment import exceptions, translation, definitions, interactive
from hostattachment.classes import AttachmentConfiguration
from hostattachment.definitions import ATTACHMENT_FC, ATTACHMENT_ISCSI

def get_basepath():
    return normpath(project_root_path.find(realpath(__file__)))

def get_backuppath():
    basepath = get_basepath()
    return join(basepath,'backup')

def try_and_catch(func):
    def call(*args, **kwargs):
        try:
            return func(*args, **kwargs)
        except exceptions.HostAttachmentError, e:
            logging.error("HostAttachmentError: %s" % str(e))
            print translation.WIZARD_SEPARATOR
            print_in_color("ERROR: %s" % str(e), 'red')
            print "The utility will now exit."
            interactive.enter_to_exit("")
            sys.exit(definitions.EXIT_CODE_GENERAL_ERROR)
        except exceptions.RebootRequiredException, e:
            logging.error("RebootRequiredException: %s" % str(e))
            print translation.WIZARD_SEPARATOR
            print_in_color(translation.REBOOT_REQUIRED, 'yellow')
            interactive.enter_to_exit("")
            sys.exit(definitions.EXIT_CODE_REBOOT_REQUIRED)
        except (exceptions.UserAbortException, KeyboardInterrupt, EOFError), e:
            logging.error("UserAbortException: %s" % str(e))
            print "\n%s" % translation.WIZARD_SEPARATOR
            print_in_color(translation.USER_ABORT, 'yellow')
            interactive.enter_to_exit("")
            sys.exit(definitions.EXIT_CODE_USER_ABORT)
    call.__name__ = func.__name__
    call.__dict__ = func.__dict__
    call.__doc__  = func.__doc__
    return call

def get_iscsi_attachment(verbose=True):
    try:
        from hostattachment.platform import ISCSIAttachment
        return ISCSIAttachment(verbose)
    except exceptions.IscsiNotDetectedError, e:
        print str(e)
        logging.warning(str(e))
    except (ImportError, NotImplementedError), e:
        logging.error(str(e))
        return None
        
def get_fc_attachment(verbose=True):
    try:
        from hostattachment.platform import FCAttachment
        return FCAttachment(verbose)
    except (ImportError, NotImplementedError), e:
        logging.error(str(e))
        return None

def get_available_attachments():
    available_attachments = list()
    iscsi = get_iscsi_attachment(False)
    fc = get_fc_attachment(False)
    if iscsi is not None:
        available_attachments.append((iscsi, ATTACHMENT_ISCSI))
    if fc is not None:
        available_attachments.append((fc, ATTACHMENT_FC))
    return available_attachments

backup_path = get_backuppath()
configuration = AttachmentConfiguration.getConfiguration()
configuration.set_backup_path(backup_path)
