#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#------------------------------------------------------------------------------------------------- 

import logging

from xiv_xsf.scsy import exceptions as scsy_exceptions
from xiv_xsf.nextra.phase10.client import exceptions as p10client_exceptions
from xiv_xsf.nextra.phase10.client.xcli import exceptions as xcli_exceptions

MAXIMUM_RETRIES = 3
def endpoints_exhausted(func):
    def call(*args, **kwargs):
        """
        calling func three times if got endpoints exhausted or reception failure
        """
        for retry_counter in range(MAXIMUM_RETRIES):
            try:
                return func(*args, **kwargs)
            except Exception, e:
                logging.debug('function %s caught %s' % (func.__name__,str(e)))
                if 'endpoints exhausted' in str(e):
                    if retry_counter == MAXIMUM_RETRIES-1:
                        raise e
                    continue
                if 'reception failure' in str(e):
                    if retry_counter == MAXIMUM_RETRIES-1:
                        raise e
                    continue
                if 'Insufficient system resources' in str(e):
                    logging.debug('function %s did not have enough resources' % func.__name__)
                else:
                    logging.debug('function %s raised an exception: %s' % (func.__name__, str(e)))
                raise e
    call.__name__ = func.__name__
    call.__dict__ = func.__dict__
    call.__doc__  = func.__doc__
    return call

def scsy_exceptions_catcher(func):
    def call(*args, **kwargs):
        try:
            return func(*args, **kwargs)
        except scsy_exceptions.BaseScsiException, e:
            logging.debug('function %s caught scsy exception: %s' % (func.__name__,str(e)))
            return None
    call.__name__ = func.__name__
    call.__dict__ = func.__dict__
    call.__doc__  = func.__doc__
    return call

