#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#-------------------------------------------------------------------------------------------------

import logging
import re

from scsi_host import ScsiHost, get_wwn_from_file
from hostattachment.platform.linux import messages

class QlogicHost(ScsiHost):
    def __init__(self, host_name):
        ScsiHost.__init__(self, host_name)
        self.type = 'QLOGIC'

    def get_wwn(self):
        wwn = None
        try:
            wwn = get_wwn_from_file('/sys/class/fc_host/%s/port_name' % (self.host_name))
        except IOError:
            pass
        if wwn is None:
            try:
                host_file = open('/proc/scsi/qla2xxx/%s' % (self.host_name_number), 'ro')
                for line in host_file.read().splitlines():
                    if line.__contains__('adapter-port'):
                        wwn = re.sub(r'(..)', r'\1:', line.split('=')[1].split(';')[0]).strip(':')
                host_file.close()
            except IOError:
                pass
        if wwn is None or wwn.isspace():
            logging.error(messages.FAILED_RETRIEVING_WWN % (self.host_name))
            self.wwn = ''
        else:
            self.wwn = wwn
