#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#-------------------------------------------------------------------------------------------------

import logging
import re

from hostattachment.platform.linux.execute import ExternalCommand
from hostattachment.platform.linux import scsi_device_manager, messages

class ScsiHost(object):
    def __init__(self, scsi_host):
        self.host_name = scsi_host
        self.host_name_number = scsi_host.replace('host', '')
        self.get_wwn()
        self.type = 'unknown type'

    def issue_lip(self):
        issue_lip_command = ExternalCommand(''' echo 1 > /sys/class/fc_host/%s/issue_lip''' % (self.host_name))
        issue_lip_command.execute()
        if issue_lip_command.return_value == 256:
            logging.debug('failed to echo 1 to issue_lip, but that is alright - the adapter does not support it')

    def get_wwn(self):
        wwn = None
        try:
            wwn = get_wwn_from_file('/sys/class/fc_host/%s/port_name' % (self.host_name))
        except IOError:
            pass

        if wwn is None:
            try:
                wwn = get_wwn_from_file('/sys/class/scsi_host/%s/port_name' % (self.host_name))
            except IOError:
                pass

        if wwn is not None:
            self.wwn = wwn
            logging.debug(messages.FAILED_RETRIEVING_WWN % (self.host_name))
        else:
            self.wwn = ''

    def remove_bad_luns(self):
        scsi_device_manager.remove_bad_luns(self.host_name)

    def add_new_luns(self):
        scsi_device_manager.add_new_luns(self.host_name)

def get_wwn_from_hex_string(hex_input):
    """
    >>> 0x0011223344556677
    00:11:22:33:44:55:66:77
    """
    wwn = re.sub(r'(..)', r'\1:', hex_input.partition("x")[2]).strip(':')

    return wwn

def get_wwn_from_file(filename):
    f = file(filename)
    first_line = f.readline().strip()
    f.close()

    return get_wwn_from_hex_string(first_line)
