#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#-------------------------------------------------------------------------------------------------

import logging

from hostattachment.iscsicommon import test_iscsi_connectivity
from hostattachment.platform.linux.execute import ExternalCommand
from hostattachment.platform.linux.iscsi import remove_bad_luns_from_all_iscsi_hosts
from hostattachment.platform.linux import messages

from iscsid_conf import ConfigFileLinuxIscsi

class ConnectionManager(object):
    def __init__(self):
        self.iscsi_conf = ConfigFileLinuxIscsi('/etc/iscsi.conf')
    
    def connect(self, ip_address, chap_name, chap_password):
        test_iscsi_connectivity(ip_address)

        logging.info('adding IP address %s to the configuration' % ip_address)
        self.discover(ip_address, chap_name, chap_password)
        self.iscsi_scan()
        return True

    def disconnect(self, ip_address):
        logging.info('removing IP address %s from the configuration' % ip_address)
        self.undiscover(ip_address)
        print messages.MANUAL_ISCSI_RESTART_IS_NEEDED
        return True

    def verify_discovered_address(self, ip_address):
        self.iscsi_conf.read()
        for target in self.iscsi_conf.targets:
            if target.ip_address == ip_address:
                return True
        return False

    def discover(self, ip_address, chap_name, chap_password):
        self.iscsi_conf.read()
        self.iscsi_conf.add_target(ip_address, chap_name, chap_password)
        self.iscsi_conf.write_to_file()

    def undiscover(self, ip_address):
        self.iscsi_conf.read()
        self.iscsi_conf.remove_target(ip_address)
        self.iscsi_conf.write_to_file()

    def iscsi_scan(self):
        logging.info(messages.REMOVING_BAD_LUNS)
        remove_bad_luns_from_all_iscsi_hosts()
        logging.info(messages.ISCSI_DAEMON_RELOAD)
        start = ExternalCommand('/etc/init.d/iscsi reload')
        start.execute()


    def is_configured(self):
        return True

    def print_all(self):
        self.print_discoveries()
        self.print_connections()

    def print_connections(self):
        logging.info('iSCSI Connections')
        print_command = ExternalCommand('iscsi-ls')
        print_command.execute()
        for line in print_command.output.splitlines():
            print line

    def print_discoveries(self):
        logging.info('iSCSI Discovery Addresses')
        self.iscsi_conf.read()
        for target in self.iscsi_conf.targets:
            print 'DiscoveryAddress=%s' % target.ip_address

