#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#-------------------------------------------------------------------------------------------------

import logging

from hostattachment.platform.linux.execute import ExternalCommand
from hostattachment.platform.linux.service import GenericServiceManager
from hostattachment.exceptions import HostAttachmentError
from hostattachment.classes import Task
from hostattachment.platform.linux.multipath.multipath_conf import MultipathConf
from hostattachment.platform.linux.multipath.udev_rules import UdevRules
from xiv_xsf.host.os.linux import get_distro_version
from xiv_xsf.utils.system_command import SystemCommand, ExternalCommandError

class MultipathdServiceTask(Task):
    def __init__(self):
        Task.__init__(self, "multipathd service", None)
        self.multipathd = GenericServiceManager(init_script = "multipathd",
                                                daemon_name = "multipathd")

    def configure(self):
        self.multipathd.configure()

    def verify(self):
        return self.multipathd.is_configured()

class MultipathConfTask(Task):
    def __init__(self):
        Task.__init__(self, "multipath.conf", None)
        self.multipath_conf = MultipathConf()

    def configure(self):
        self.multipath_conf.configure()

        # If multipathd is already running, call reload.
        # Restart was disabled on RHEL >= 5.3 when boot-from-san
        multipathd = GenericServiceManager(init_script = "multipathd",
                                           daemon_name = "multipathd")
        (distro, major, minor) = get_distro_version()
        if multipathd.status() == 0:
            # On SLES (at least 10.2, 11.0) reload doesn't work at all, so we
            # manually send HUP
            if distro == "suse":
                proc = ExternalCommand("killproc -HUP multipathd")
                proc.execute()
                if proc.return_value != 0:
                    raise HostAttachmentError("Failed sending HUP to multipathd")
            else:
                multipathd.reload()

    def verify(self):
        return self.multipath_conf.is_configured()

class UdevRulesTask(Task):
    def __init__(self):
        Task.__init__(self, "udev multipath rules", None)
        self.udev_rules = UdevRules()

    def configure(self):
        self.udev_rules.configure()

    def verify(self):
        return self.udev_rules.is_configured()
