#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#-------------------------------------------------------------------------------------------------

import logging

class Singleton(object):
    __instance = None
    def __init__(self):
        if Singleton.__instance is None:
            Singleton.__instance = Tracer()

    def __getattr__(self, attr):
        return getattr(self.__instance, attr)

    def __setattr__(self, attr, value):
        return setattr(self.__instance, attr, value)
                            
class Tracer(object):
    def __init__(self):
        self.prefix = "trace"
        self.indent_level=0
        pass

    def entry(self, logged_class, function, *args, **kwargs):
        arguments_formatted = ", ".join(str(arg) for arg in args)
        keyword_arguments_formatted = ", ".join("%s=%s" % \
                                                (key, value) for key, value \
                                                in kwargs.items())
        function_formatted = '%s.%s' % (logged_class.__name__, function.__name__)
        entry_message_formatted = '> %s (%s, %s)' % (function_formatted, \
                                                     arguments_formatted, \
                                                     keyword_arguments_formatted)
        self.debug(entry_message_formatted)
        self.indent_level += 1

    def exit(self, logged_class, function, result):
        self.indent_level -= 1
        exit_message_formatted = '< %s.%s = %s' % (logged_class.__name__, \
                                                   function.__name__, result)
        self.debug(exit_message_formatted)

    def debug(self, message):
        self.log(logging.DEBUG, message)

    def info(self, message):
        self.log(logging.INFO, message)

    def warn(self, message):
        self.log(logging.WARN, message)

    def error(self, message):
        self.log(logging.ERROR, message)

    def log(self, level, message):
        identation_formatted = '%s: %s' % (self.prefix, ' '*self.indent_level)
        if message[0] != '>' and message[0] != '<':
            message = ' ' + message
        logging.log(level, '%s %s' %(identation_formatted, message))

    def trace_a_class(self, class_to_trace):
        def tracer(func):
            def callable(*args, **kwargs):
                self.entry(class_to_trace, func, *args, **kwargs)
                result = func(*args, **kwargs)
                self.exit(class_to_trace, func, result)
                return result
            callable.__name__ = func.__name__
            return callable
        if not hasattr(class_to_trace, '_trace_is_active'):
            for attribute_name, attribute_value in class_to_trace.__dict__.iteritems():
                if type(attribute_value).__name__ == 'function':
                    setattr(class_to_trace, attribute_name, tracer(attribute_value))
            setattr(class_to_trace,'_trace_is_active',True)

tracer = Singleton()
