#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#------------------------------------------------------------------------------------------------- 

import sys, logging

from xiv_xsf.console import print_in_color
from hostattachment import translation, interactive, admin, exceptions, definitions
from hostattachment.definitions import ATTACHMENT_FC, ATTACHMENT_ISCSI

def print_separator():
    print_in_color(translation.WIZARD_SEPARATOR,"white")

@admin.try_and_catch
def attach_welcome():
    """
    prints the wizard banner, and waits for the user to press the entry key
    before proceeding to validate the host
    """
    print_separator()
    print translation.WIZARD_ATTACH_BANNER + "\n"
    interactive.enter_to_proceed(translation.WIZARD_VALIDATE)
    print_separator()

@admin.try_and_catch
def detach_welcome():
    """
    prints the wizard banner, and waits for the user to press the entry key
    before proceeding to validate the host
    """
    print_separator()
    print translation.WIZARD_DETACH_BANNER + "\n"
    if not interactive.prompt(translation.WIZARD_DETACH_WARNING):
        raise exceptions.UserAbortException()

@admin.try_and_catch
def select_an_attachment():
    available_attachments = admin.get_available_attachments()
    if len(available_attachments) is 0:
        logging.error('No attachments available')
        print 'ERROR: No attachments available'
        raise exceptions.HostAttachmentError()
    selected_attachment_type = offer_attachments(available_attachments)
    if selected_attachment_type is None:
        raise exceptions.UserAbortException()
    attachment = get_selected_attachment(available_attachments, selected_attachment_type)
    attachment.handle_additional_options(options=None, is_interactive=True)
    return attachment, selected_attachment_type
    
@admin.try_and_catch
def offer_attachments(available_attachments):
    if is_fc_available(available_attachments) and is_iscsi_available(available_attachments):
        return interactive.choose_connectivity_type()
    if is_fc_available(available_attachments) and \
            interactive.prompt(translation.ONLY_FC_PROMPT, default_answer="yes"):
                return ATTACHMENT_FC
    if is_iscsi_available(available_attachments) and \
            interactive.prompt(translation.ONLY_ISCSI_PROMPT, default_answer="yes"):
                return ATTACHMENT_ISCSI
    return None

def is_fc_available(available_attachments):
    for (attachment, attachment_type) in available_attachments:
        if attachment_type == ATTACHMENT_FC:
            return True
    return False

def is_iscsi_available(available_attachments):
    for (attachment, attachment_type) in available_attachments:
        if attachment_type == ATTACHMENT_ISCSI:
            return True
    return False

def get_selected_attachment(available_attachments, selected_attachment_type):
    for (attachment, attachment_type) in available_attachments:
        if attachment_type == selected_attachment_type:
            return attachment

def attach_end():
    print_separator()
    print translation.WIZARD_ATTACH_ENDED
    interactive.enter_to_exit("")
    sys.exit(definitions.EXIT_CODE_GENERAL_ERROR)
    
def detach_end():
    print_separator()
    print translation.WIZARD_DETACH_ENDED
    interactive.enter_to_exit("")
    sys.exit(definitions.EXIT_CODE_GENERAL_ERROR)
    
@admin.try_and_catch
def check_supported(attachment):
    if not attachment.is_platform_officially_supported():
        print_separator()
        raise exceptions.HostAttachmentError(translation.UNSUPPORTED_OS)
