#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#------------------------------------------------------------------------------------------------- 

import sys
import logging

from hostattachment import definitions, exceptions, admin
from hostattachment import logger, translation, parser_config
from xiv_xsf.console import print_in_color

def attachment_not_supported(attachment_type):
    if attachment_type == definitions.ATTACHMENT_ISCSI:
        logging.error(translation.NOT_SUPPORTED_ISCSI)
        sys.stderr.write("%s\n" % translation.NOT_SUPPORTED_ISCSI)
    if attachment_type == definitions.ATTACHMENT_FC:
        logging.error(translation.NOT_SUPPORTED_FC)
        sys.stderr.write("%s\n" % translation.NOT_SUPPORTED_FC)
    else:
        pass
    sys.exit(definitions.EXIT_CODE_GENERAL_ERROR)
    
def handle_commandline_arguments(attachment_type):
    attachment = get_attachment(attachment_type)
    parser = parser_config.get_attachment_option_parser(attachment)
    options, args = parser.parse_args(sys.argv)
    if len(sys.argv) <= 1:
        """
        If not arguments were given
        """
        parser.print_help()
        sys.exit(definitions.EXIT_CODE_SUCCESS)
    try:
        """
        Process the commandline argument
        """
        if attachment_type == definitions.ATTACHMENT_ISCSI:
            if not parser_config.iscsi_handler(attachment, options):
                parser.print_help()
        elif attachment_type == definitions.ATTACHMENT_FC:
            if not parser_config.fc_handler(attachment, options):
                parser.print_help()
        sys.exit(definitions.EXIT_CODE_SUCCESS)
    except exceptions.HostAttachmentError, e:
        print_in_color('ERROR: %s' % str(e), 'red')
        sys.exit(definitions.EXIT_CODE_GENERAL_ERROR)
    except exceptions.RebootRequiredException, e:
        print_in_color(translation.REBOOT_REQUIRED, 'yellow')
        sys.exit(definitions.EXIT_CODE_REBOOT_REQUIRED)
    except exceptions.VerifyFailedError, e:
        sys.exit(definitions.EXIT_CODE_VERIFY_FAILED)
        
def get_attachment(attachment_type):
    attachment = None 
    if attachment_type == definitions.ATTACHMENT_ISCSI:
        attachment = admin.get_iscsi_attachment()
    elif attachment_type == definitions.ATTACHMENT_FC:
        attachment = admin.get_fc_attachment()
    if attachment is None:
        attachment_not_supported(attachment_type)
    return attachment

