#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#------------------------------------------------------------------------------------------------- 

import sys
import logging

from hostattachment import definitions, exceptions
from hostattachment import logger, translation, interactive, admin, array
from hostattachment.definitions import ATTACHMENT_FC, ATTACHMENT_ISCSI
from hostattachment.wizard_assistant import *

class Wizard(object):
    def __init__(self):
        pass
    
    def start(self):
        """
        The wizard starts here
        """
        attach_welcome()
        self.attachment, self.selected_attachment_type = select_an_attachment()
        check_supported(self.attachment)
        self.verify_and_configure()
        if self.is_iscsi_attached():
            self.discover_iscsi_targets()
        if self.is_fc_attached():
            self.rescan_fc_devices()
        array.define_xiv_storage_arrays(self.attachment)
        attach_end()
    
    @admin.try_and_catch
    def verify_and_configure(self):
        print_separator()
        print translation.HOST_CONFIG_VALIDATION_NOTIFICATION; sys.stdout.flush()
        if not self.attachment.verify():
            while True:
                if interactive.prompt(translation.HOST_CONFIG_PROMPT, default_answer="yes"):
                    break
                if interactive.prompt(translation.USER_ABORT_CONFIRM):
                    raise exceptions.UserAbortException()
            print translation.HOST_CONFIG_WAIT; sys.stdout.flush()
            self.attachment.config()
            print translation.HOST_CONFIG_SUCCESS
        else:
            print translation.HOST_ALREADY_CONFIGURED
    
    def is_iscsi_attached(self):
        return self.selected_attachment_type == ATTACHMENT_ISCSI
    
    def is_fc_attached(self):
        return self.selected_attachment_type == ATTACHMENT_FC
    
    @admin.try_and_catch
    def iscsi_connect_prompt(self):
        while True:
            if not interactive.prompt(translation.NEW_ISCSI_CONNECT, default_answer="yes"):
                if interactive.prompt(translation.ISCSI_RESCAN_PROMPT, default_answer="yes"):
                    self.attachment.rescan()
                return None
            try:
                address = interactive.prompt_iscsi_address(translation.ISCSI_CONNECT_ADDR)
                if not interactive.prompt(translation.ISCSI_CHAP_REQUEST):
                    self.attachment.connect_iscsi(address)
                    continue
                chap_name = interactive.prompt_iscsi_chap_name()
                chap_secret = interactive.prompt_iscsi_chap_secret()
                self.attachment.connect_iscsi(address, chap_name, chap_secret)
            except exceptions.HostAttachmentError, e:
                interactive.enter_to_proceed(str(e))
                
    @admin.try_and_catch
    def discover_iscsi_targets(self):
        print_separator()
        self.iscsi_connect_prompt()

    def wizard_connect_new_devices(self):
        print_separator()
        return interactive.prompt(translation.DISCOVER_NEW_DEVICES_PROMPT, 
                                  default_answer="yes")

    @admin.try_and_catch
    def rescan_fc_devices(self):
        print_separator()
        print translation.XIV_FC_HOST_DEFINE
        fc_ports = self.attachment.get_storage_ports()
        print_in_color("\n".join([str(fc_port) for fc_port in fc_ports]),'cyan',newline=False)
        interactive.enter_to_proceed("")
        if interactive.prompt(translation.FC_RESCAN_PROMPT, default_answer="yes"):
            print translation.HOST_RESCAN_WAIT; sys.stdout.flush()
            self.attachment.rescan()
            
def main():
    wizard = Wizard()
    return wizard.start()
