#!/usr/bin/env xpyv
#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#------------------------------------------------------------------------------------------------- 

import sys
import logging
import os

from xpyv import project_root_path

# Ignore all warnings of type DeprecationWarning:
import warnings
warnings.filterwarnings('ignore',category=DeprecationWarning)

def get_list_of_eggs(directory=os.curdir):
    """ 
    returns a list of all files with an egg extension 
    from a given directory (current directory by default)
    """
    list_of_eggs = []
    for filename in os.listdir(directory):
        if filename.endswith('egg'):
            list_of_eggs.append(filename)
    return list_of_eggs

def remove_old_eggs_from_list(list_of_eggs):
    """
    given a list of egg files, this method first sorts the list, 
    then removes the older version of the same egg package
    """
    list_of_eggs.sort()
    an_old_egg = get_an_old_egg_from_list(list_of_eggs)
    while an_old_egg:
        list_of_eggs.remove(an_old_egg)
        an_old_egg = get_an_old_egg_from_list(list_of_eggs)
    
def append_list_of_eggs_to_path(list_of_eggs, eggs_base=os.curdir):
    """
    appends to the path a list of egg files by their absolute path, 
    so stuff from those eggs could get imported
    """
    for egg in list_of_eggs:
        sys.path.append(os.path.abspath(os.path.join(eggs_base,egg)))

def get_an_old_egg_from_list(list_of_eggs):
    """
    given a list of egg files, 
    this method returns the first filename of an old-version egg
    """
    for i in range(1,len(list_of_eggs)):
        if list_of_eggs[i].split('-')[0] == list_of_eggs[i-1].split('-')[0]:
            return list_of_eggs[i-1]
    return None
   
def get_basepath():
    return os.path.normpath(project_root_path.find(os.path.realpath(__file__)))

def initialize_project():
    basepath = get_basepath()
    sys.path.append(os.path.join(basepath,'lib'))
    eggs = get_list_of_eggs(os.path.join(basepath,'deps'))
    remove_old_eggs_from_list(eggs)
    if len(eggs) > 0:
        append_list_of_eggs_to_path(eggs, os.path.join(basepath,'deps'))
    else:
        sys.path.append(os.path.join(basepath,'deps'))

if __name__ == '__main__':
    initialize_project()
    import IPython
    IPython.Shell.start().mainloop()

