#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#------------------------------------------------------------------------------------------------- 

from xiv.dtypes import Bunch

class DataField(Bunch):
    def __init__(self, name, description, length=0, displayname=None, xiv_specific=False, hex_id=False):
        Bunch.__init__(self)
        self.name = name
        if displayname is None:
            self.displayname = self.capitalize_name()
        else:
            self.displayname = displayname
        self.description = description
        self.length = length
        self.xiv_specific = xiv_specific
        self.is_hex = hex_id
    
    def capitalize_name(self):
        capitalized_name = ''
        for item in self.name.split('_'):
            capitalized_name += '%s ' % item.capitalize()
        return capitalized_name.replace('Xiv', 'XIV')
 
AVAILABLE_FIELDS = [
    DataField('device',    'Name of the OS device'),
    DataField('size',      'Size of the device', 7),
    DataField('serial',    'SCSI unit serial number', 11),
    DataField('lun',       'SCSI Logical Unit Number',3),
    DataField('multipath', 'Multipath information: Active vs Total available Paths', \
              length=6, displayname = 'Paths'),
    DataField('vendor',    'SCSI vendor', 8),
    DataField('vol_name',  'Name of the XIV Volume', xiv_specific=True),
    DataField('vol_id',    'Volume ID in the XIV', 4, xiv_specific=True, hex_id=True),
    DataField('xiv_id',    'ID of the XIV', 7, xiv_specific=True, hex_id=True),
    DataField('xiv_host',  'Name of the host, as configured in the XIV', xiv_specific=True)
    ]

DEFAULT_FIELDS = [
    AVAILABLE_FIELDS[0],
    AVAILABLE_FIELDS[1],
    AVAILABLE_FIELDS[4],
    AVAILABLE_FIELDS[6],
    AVAILABLE_FIELDS[7],
    AVAILABLE_FIELDS[8],
    AVAILABLE_FIELDS[9]
]

IS_XIV_DEVICE = DataField('is_xiv_device', 'True if XIV')

def get_available_fields_names():
    names = []
    for field in AVAILABLE_FIELDS:
        names.append(field.name)
    return names
