#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#------------------------------------------------------------------------------------------------- 

import sys
from xiv_xsf.console import print_in_color

from xiv_xsf.host.storage.multipath import MultipathDevice, MultipathInfoError,\
    get_all_multipath_devices, get_all_non_multipath_devices,\
    MP_NATIVE, MP_VERITAS, MP_AUTO
from xiv_xsf.scsy.exceptions import ScsiStatusCheckCondition, CannotOpenDeviceError

class BadArgsError(Exception):
    pass

def exception_info():
    tb = sys.exc_info()[2]
    retval = []
    while tb:
        co = tb.tb_frame.f_code
        retval.append("%s:%d" % (co.co_filename, tb.tb_lineno))
        tb = tb.tb_next

    return retval

def exception_catcher(func):
    def call(*args, **kwargs):
        try:
            return func(*args, **kwargs)
        except BadArgsError, e:
            print >> sys.stderr, e.args[0]
            print
            sys.exit(1)
        except MultipathInfoError, e:
            print_in_color ("\nError fetching multipath info", 'red')
            print_in_color ("DEBUG INFO: %s" % exception_info(), 'yellow')
            sys.exit(1)
        except KeyboardInterrupt, e:
            sys.exit(1)
        except Exception, e:
            print_in_color ("\nGeneral error", 'red')
            print_in_color ("DEBUG INFO: %s, %s" % (exception_info(), str(e)), 'yellow')
            sys.exit(2)

    call.__name__ = func.__name__
    call.__dict__ = func.__dict__
    call.__doc__  = func.__doc__
    return call

