#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#-------------------------------------------------------------------------------------------------

import os
import sys
import logging
from logging.handlers import RotatingFileHandler
from os.path import normpath, realpath

from xpyv import project_root_path
from xiv_xsf.utils.osutils import get_os_name

# Dynamic pythonpath and logging directory
pkg_basepath = normpath(project_root_path.find(realpath(__file__)))

if get_os_name() == 'windows':
    logging_path = os.path.join(os.environ['SystemRoot'],'temp')
elif os.uname()[0] == 'HP-UX':
        logging_path = os.path.join('/','var','adm')
else:
    logging_path = os.path.join('/','var','log')

from hostattachment import definitions

# Handle logging
LOG_FILENAME = logging_path + "/xiv_devlist.log"
try:
    logfile_handler = RotatingFileHandler(LOG_FILENAME, mode="a", maxBytes=2000000, backupCount=50)
except IOError, e:
    sys.stderr.write("Failed to initiate logging: " + str(e) + "\n")
    sys.exit(definitions.EXIT_CODE_GENERAL_ERROR)
logfile_handler.doRollover()
logging_format = logging.Formatter(datefmt='%Y-%m-%d %H:%M:%S',
    fmt='%(asctime)s %(levelname)-8s %(message)s')
logfile_handler.setFormatter(logging_format)
logger = logging.getLogger()
logger.setLevel(logging.DEBUG)
logger.addHandler(logfile_handler)
