#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#------------------------------------------------------------------------------------------------- 

import sys
from optparse import OptionParser
from excpts import exception_catcher, BadArgsError
from config import AVAILABLE_FIELDS, DEFAULT_FIELDS, get_available_fields_names
from xiv_xsf.host.storage.multipath import MultipathDevice, MultipathInfoError,\
    get_all_multipath_devices, get_all_non_multipath_devices,\
    MP_NATIVE, MP_VERITAS, MP_AUTO

def list_fields():
    print "Syntax of the -o option:"
    print "     xiv_devlist -o field1,field2,field3"
    print
    print "Available fields:"
    for field in AVAILABLE_FIELDS:
        fieldstr = "%s:" % field.name
        print "%s %s" % (fieldstr.ljust(14), field.description)
    print
    print "all: for all available fields"
    print
    sys.exit(1)

@exception_catcher
def parse_args(argv):
    """Parse all cli arguments"""

    parser = OptionParser()
    out_options = [ "tui", "csv", "xml" ]
    parser.add_option("-t", "--out",
        action="store", dest="out", type="string", default = "tui",
        help="Choose output method: tui, csv, xml (default: tui)")

    parser.add_option("-o", "--options", action = "store", dest = "fields",
        type = "string", default = None, help = "Fields to display; "+\
        "Comma-separated, no spaces. Use -l to see the list of fields")
    
    parser.add_option("-H", "--hex", action = "store_true", dest = "hex", 
        default = False, help = "Display XIV volume and machine IDs in hexadecimal base")

    parser.add_option("-d", "--debug", action = "store_true", dest = "debug", 
        default = False, help = "Enable debug logging")
    
    parser.add_option("-l", "--list-fields", action = "store_true", 
        dest = "list_fields", help = "List available fields for the -o option",
        default = False)

    parser.add_option("-m", "--multipath", action = "store", 
        dest = "mp_framework_str", help = "Enforce a multipathing framework"+\
            " <auto|native|veritas>", default = "auto")

    parser.add_option("-x", "--xiv-only", action = "store_true", dest = "xiv_only", 
        default = False, help = "Print only XIV devices")

    (options, args) = parser.parse_args()
    if (args != []):
        raise BadArgsError("Unknown option %s" % args[0])

    try:
        if (options.help == True):
            parser.print_help()
            sys.exit(0)
    except AttributeError, e:
        pass

    if (options.list_fields):
        list_fields()

    if (options.out not in out_options):
        raise BadArgsError("Bad output type was used: \"%s\"\n" % options.out +\
            "Use --help to fix your command line")

    if (options.fields is None):
        options.fields = DEFAULT_FIELDS
    
    elif (options.fields.strip().lower() == 'all'):
        options.fields = AVAILABLE_FIELDS
    
    else:
        # Check fields
        fields = options.fields.split(",")
        fields = map(lambda(x): x.strip(), fields) # clear spaces
        badargs = filter(lambda(x): x not in get_available_fields_names(), fields)
        if badargs != []:
            raise BadArgsError("Bad field was used: \"%s\"\n" % badargs[0] +\
                "Usage: -o field1,field2,field3,...\n\n" +
                "Use -l for listing possible fields")

        options.fields = []
        for field in fields:
            for available_field in AVAILABLE_FIELDS:
                if field.lower().strip() == available_field.name:
                    options.fields.append(available_field)

    # mp_framework
    if (options.mp_framework_str == "auto"):
        options.mp_framework = MP_AUTO
    elif (options.mp_framework_str == "veritas"):
        options.mp_framework = MP_VERITAS
    elif (options.mp_framework_str == "native"):
        options.mp_framework = MP_NATIVE
    else:
        raise BadArgsError(\
            "Bad multipath parameter: \"%s\"\n" % (options.mp_framework_str)+\
            "Usage: -m <auto|native|veritas>")

    return options
