#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#------------------------------------------------------------------------------------------------- 

"""
xiv_devlist: XIV volume info command line utility
"""

import sys

from xiv_xsf.console import print_in_color, is_root
from parser import parse_args
from data import DevListData, DevListFieldHandler
from config import AVAILABLE_FIELDS, DEFAULT_FIELDS, IS_XIV_DEVICE
from output import CommaSeperatedValues, ColoredTable, XmlFormat
from excpts import exception_catcher

def set_debug_logging():
    import logger
    from hostattachment.tracing import tracer
    tracer.trace_a_class(DevListData)
    tracer.trace_a_class(DevListFieldHandler)
    tracer.trace_a_class(CommaSeperatedValues)
    tracer.trace_a_class(ColoredTable)
    tracer.trace_a_class(XmlFormat)

@exception_catcher
def main():
    if not is_root():
        print_in_color('you must have root/administrator access to use this utility.', 'red')
        sys.exit(1)
    options = parse_args(sys.argv)

    if options.debug:
        set_debug_logging()
    devlist = DevListData([IS_XIV_DEVICE] + options.fields, mp_framework = options.mp_framework)

    if (options.out == "tui"):
        print "Loading disk info...",
        sys.stdout.flush()
    # Read the data into the object
    devlist.populate_data()

    if (options.out == "tui"):
        print "\r", 80*" ", "\r",

    devlist.mk_sorted_list()
    
    if options.hex:
        for device in devlist.sorted_devices_list["xiv"]:
            for field in AVAILABLE_FIELDS:
                if field.is_hex:
                    try:
                        device[field.name] = hex(int(str(device[field.name]),10)).strip('0x').upper()
                    except:
                        if field.name == 'xiv_id':
                            dec_sn = device[field.name]
                            device[field.name] = '%s%s' % (dec_sn[:2], hex(int(str(dec_sn[2:]),10)).strip('0x').upper().zfill(5))
                        pass
    
    if (options.out == 'tui'):
        print_in_color("XIV Devices", 'white')
        ColoredTable(options.fields, devlist.sorted_devices_list["xiv"], True).output()
        if not options.xiv_only:
            print "\n"
            print_in_color("Non-XIV Devices", 'white')
            ColoredTable(options.fields, devlist.sorted_devices_list["nonxiv"], False).output()
            
    if (options.out == 'csv'):
        if options.xiv_only:
            CommaSeperatedValues(options.fields, devlist.sorted_devices_list["xiv"]).output()
        if not options.xiv_only:
            CommaSeperatedValues([IS_XIV_DEVICE] + options.fields, 
                                 devlist.sorted_devices_list["xiv"] + devlist.sorted_devices_list["nonxiv"]).output()
    
    if (options.out == 'xml'):
        if options.xiv_only:
            XmlFormat(options.fields, devlist.sorted_devices_list["xiv"]).output()
        else:
            XmlFormat([IS_XIV_DEVICE] + options.fields, 
                      devlist.sorted_devices_list['xiv'] + devlist.sorted_devices_list["nonxiv"]).output()
    
    if len(devlist.errored_devices):
        sys.stderr.write("Unreachable devices: %s\n" % ' '.join(devlist.errored_devices))
        sys.stderr.flush()
    
