#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program  
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
# 
#-------------------------------------------------------------------------------------------------   

import threading
from exceptions import CollectorTimedOut, CollectionError

TIMEOUT = 10

class InterruptableThread(threading.Thread):
    def __init__(self, func, *args, **kwargs):
        threading.Thread.__init__(self)
        self.result = None
        self.func = func
        self.args = args
        self.kwargs = kwargs

    def run(self):
        try:
            from xpyv import Wow64FsRedirection
            Wow64FsRedirection.disable()
        except (ImportError), e:
            pass
        try:
            self.result = self.func(*self.args, **self.kwargs)
        except (CollectionError), e:
            self.result = ('CollectionError', str(e))
        try:
            from xpyv import Wow64FsRedirection
            Wow64FsRedirection.enable()
        except (ImportError), e:
            pass


class CollectorThread(object):
    def __init__(self, timeout=TIMEOUT):
        self.timeout = timeout

    def run(self, collectable, *args, **kwargs):
        interruptable_thread = InterruptableThread(collectable._collect, *args, **kwargs)
        interruptable_thread.start()
        interruptable_thread.join(self.timeout)
        if interruptable_thread.isAlive():
            if hasattr(collectable, "proc"):
                collectable.proc.kill()
            raise CollectorTimedOut('thread has timed out')
        else:
            if str(type(interruptable_thread.result)) == "<type 'tuple'>":
                raise CollectionError(interruptable_thread.result[1])
            return interruptable_thread.result

    def thread(self, collectable):
       def callable(*args, **kwargs):
            return self.run(collectable, *args, **kwargs)
       callable.__name__ = collectable.collect.__name__
       return callable


