#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program  
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
# 
#-------------------------------------------------------------------------------------------------   

from os.path import getmtime 
from time import localtime, strftime
from subprocess import PIPE, Popen

from interfaces import ICollectable
from exceptions import CollectionError 
from collector_thread import CollectorThread

TIMEOUT = 60

class SimpleCommandCollectable(ICollectable):
    def __init__(self, description, command_args, timeout=TIMEOUT):
        ICollectable.__init__(self, description)
        self.args = command_args
        self.add_attribute("command", ' '.join(self.args))
        self.add_attribute('type', 'command')
        self.collector_thread = CollectorThread(timeout)
        self.collect = self.collector_thread.thread(self)

    def _collect(self):
        try:
            self.proc = Popen(self.args, stdout=PIPE, stderr=PIPE)
            stdout, stderr = self.proc.communicate()
            self.add_attribute("returncode", self.proc.returncode)
            self.add_attribute("stdout", stdout)
            self.add_attribute("stderr", stderr)
        except (OSError), e:
            raise CollectionError(str(e))
        self.add_attribute("run-date", strftime("%m/%d/%Y %I:%M:%S %p", localtime()))

