#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program  
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
# 
#-------------------------------------------------------------------------------------------------   

from os.path import getmtime, join, isfile, isdir, islink
from time import localtime, strftime
from glob import glob

from interfaces import ICollectable
from exceptions import CollectionError
from collector_thread import CollectorThread

TIMEOUT = 60

class SimpleDirectoryCollectable(ICollectable):
    """
    Collects all files within a directory, recursively by default
    """

    def __init__(self, description, zipfile, directory_to_collect, recursive_scan=True, file_filter='*', exclusions=[], timeout=TIMEOUT) :
        ICollectable.__init__(self, description)
        self.zipfile = zipfile
        self.directory_to_collect = directory_to_collect
        self.add_attribute('type', 'directory')
        self.recursive_scan = recursive_scan
        self.filter = file_filter
        self.exclusions = exclusions
        self.collector_thread = CollectorThread(timeout)
        self.collect = self.collector_thread.thread(self)

    def _collect(self):
        try:
            self.collect_directory_to_zip(self.directory_to_collect)
        except (CollectionError), e:
            raise e
        self.add_attribute("directory-name", self.directory_to_collect)
        self.add_attribute("collect-timestamp", strftime("%m/%d/%Y %I:%M:%S %p", localtime()))

    def collect_directory_to_zip(self, directory_path):
        for file_or_directory in glob(join(directory_path, self.filter)):
            if isfile(file_or_directory):
                excluded = False
                for item in self.exclusions:
                    if file_or_directory.__contains__(item) or item.__contains__(file_or_directory):
                        excluded = True
                if not excluded:
                    try:
                        self.collect_datafile_to_zip(file_or_directory)
                    except (CollectionError), e:
                        pass
            if isdir(file_or_directory) and not islink(file_or_directory) and self.recursive_scan:
                try:
                    self.collect_directory_to_zip(file_or_directory)
                except (CollectionError), e:
                    pass

    def collect_datafile_to_zip(self, filename):
        """
        Collect data file to zip, using the in-archive name <filename_in_zip>
        also auto generates some metadata regarding the collection
        """
        try:
            self.zipfile.write(filename, filename)
        except (IOError, OSError), e:
            raise CollectionError(str(e))

 
