#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program  
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
# 
#-------------------------------------------------------------------------------------------------   

from os.path import getmtime
from time import localtime, strftime

from interfaces import ICollectable
from exceptions import CollectionError
from collector_thread import CollectorThread

TIMEOUT = 10

class SimpleFileCollectable(ICollectable):
    """
    Collect metadata and data files
    """
    def __init__(self, description, zipfile, file_to_collect, timeout=TIMEOUT):
        ICollectable.__init__(self, description)
        self.zipfile = zipfile
        self.file_to_collect = file_to_collect
        self.add_attribute('type', 'file')
        self.collector_thread = CollectorThread(timeout)
        self.collect = self.collector_thread.thread(self)

    def _collect(self):
        try:
            self.collect_datafile_to_zip(self.file_to_collect)
        except (CollectionError), e:
            raise e
        self.add_attribute("filename", self.file_to_collect)
        self.add_attribute("collect-timestamp", strftime("%m/%d/%Y %I:%M:%S %p", localtime()))
        self.add_attribute("last-modified-timestamp", strftime("%m/%d/%Y %I:%M:%S %p", localtime(getmtime(self.file_to_collect))))

    def collect_datafile_to_zip(self, filename):
        """
        Collect data file to zip, using the in-archive name <filename_in_zip>
        also auto generates some metadata regarding the collection
        """
        try:
            self.zipfile.write(filename, filename)
        except (IOError, OSError), e:
            raise CollectionError(str(e))

