#!/usr/bin/env xpyv

#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program  
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
# 
#-------------------------------------------------------------------------------------------------   

from os import path, environ
from commands import getoutput
from subprocess import PIPE, Popen

from interfaces import IXIVDiag
from collector.collectable.files import SimpleFileCollectable as FileItem
from collector.collectable.commands import SimpleCommandCollectable as CommandItem
from collector.collectable.directories import SimpleDirectoryCollectable as DirectoryItem

from xpyv import project_root_path

DEFAULTDIR = '%stmp' % (path.sep)
HOST_ATTACH_DIR = path.abspath(path.join(project_root_path.find(False)))
HOST_ATTACH_LOGDIR = path.join(HOST_ATTACH_DIR, 'log')
HOST_ATTACH_BINDIR = path.join(HOST_ATTACH_DIR, 'bin')
XIV_DEVLIST_PATH = path.join(HOST_ATTACH_BINDIR, 'xiv_devlist')
XIV_FC_ADMIN_PATH = path.join(HOST_ATTACH_BINDIR, 'xiv_fc_admin')
XIV_ISCSI_ADMIN_PATH = path.join(HOST_ATTACH_BINDIR, 'xiv_iscsi_admin')
INQUIRY_PATH = path.join(HOST_ATTACH_DIR, 'lib', 'xiv_diag', 'scripts', 'inquiry.py')

class XIVDiag(IXIVDiag):
    def add_collectables(self):
        self.add_commands()
        self.add_files()
        self.add_directories()

    def add_directories(self):
        self.add_collectable_item(DirectoryItem('/sys directory', self.zip_file, path.join(path.sep, 'sys')))
        self.add_collectable_item(DirectoryItem('/etc/udev directory', self.zip_file, path.join(path.sep, 'etc', 'udev')))
        self.add_collectable_item(DirectoryItem('/proc directory', self.zip_file, path.join(path.sep, 'proc'), False, '*', ["kcore", "kmsg"]))
        self.add_collectable_item(DirectoryItem('/dev/mapper directory', self.zip_file, path.join(path.sep, 'dev', 'mapper')))
        self.add_collectable_item(DirectoryItem('/dev/xiv-2810 directory', self.zip_file, path.join(path.sep, 'dev', 'xiv-2810')))
        self.add_collectable_item(DirectoryItem('/etc/iscsi directory', self.zip_file, path.join(path.sep, 'etc', 'iscsi')))
        self.add_collectable_item(DirectoryItem('/var/lib/iscsi directory', self.zip_file, path.join(path.sep, 'var', 'lib', 'iscsi')))

    def add_files(self):
        self.add_collectable_item(FileItem('/etc/initiatorname.iscsi', self.zip_file, path.join(path.sep, 'etc', 'initiatorname.iscsi')))
        self.add_collectable_item(FileItem('/etc/iscsi.conf', self.zip_file, path.join(path.sep, 'etc', 'iscsi.conf')))
        self.add_collectable_item(FileItem('/etc/iscsid.conf', self.zip_file, path.join(path.sep, 'etc', 'iscsid.conf')))
        # TODO: we want to add a wildcard (i.e. /var/log/messages*)
        self.add_collectable_item(FileItem('/var/log/messages', self.zip_file, path.join(path.sep, 'var', 'log', 'messages')))
        # TODO: we want to add a wildcard (i.e. /var/log/boot.log*)
        self.add_collectable_item(FileItem('/var/log/boot.log', self.zip_file, path.join(path.sep, 'var', 'log', 'boot.log')))
        self.add_collectable_item(FileItem('multipath.conf', self.zip_file, path.join(path.sep, 'etc', 'multipath.conf')))
        self.add_collectable_item(FileItem('mtab', self.zip_file, path.join(path.sep, 'etc', 'mtab')))
        # TODO: we want a wildcard
        self.add_collectable_item(FileItem('host_attach.log', self.zip_file, path.join(HOST_ATTACH_LOGDIR, 'host_attach.log')))
        # TODO EMULEX/QLOGIC specific files

    def add_commands(self):
        self.add_collectable_item(CommandItem('xiv_devlist' , [XIV_DEVLIST_PATH, '-o', 'all']))
        self.add_collectable_item(CommandItem('xiv_fc_admin -L' , [XIV_FC_ADMIN_PATH, '-L']))
        self.add_collectable_item(CommandItem('xiv_fc_admin -V' , [XIV_FC_ADMIN_PATH, '-V']))
        self.add_collectable_item(CommandItem('xiv_fc_admin -P' , [XIV_FC_ADMIN_PATH, '-P']))
        self.add_collectable_item(CommandItem('xiv_iscsi_admin -L' , [XIV_ISCSI_ADMIN_PATH, '-L']))
        self.add_collectable_item(CommandItem('xiv_iscsi_admin -V' , [XIV_ISCSI_ADMIN_PATH, '-V']))
        self.add_collectable_item(CommandItem('xiv_iscsi_admin -P' , [XIV_ISCSI_ADMIN_PATH, '-P']))
        self.add_collectable_item(CommandItem("multipath", ['multipath', '-ll']))
        self.add_collectable_item(CommandItem("ls scsi devices", ['ls', '-lR', '%s' % path.join(path.sep, 'sys', 'bus', 'scsi', '*')]))
        self.add_collectable_item(CommandItem("fdisk -l", ['fdisk', '-l']))
        self.add_collectable_item(CommandItem("lspci", ['lspci']))
        self.add_collectable_item(CommandItem("mount", ['mount']))
        self.add_collectable_item(CommandItem("lsmod", ['lsmod']))
        self.add_collectable_item(CommandItem("df", ['df']))
        self.add_collectable_item(CommandItem("uname -a", ['uname', '-a']))
        self.add_collectable_item(CommandItem("dmidecode", ['dmidecode']))
        self.add_collectable_item(CommandItem("ls /dev", ['ls', '-la', '%s' % path.join(path.sep, 'dev')]))
        self.add_collectable_item(CommandItem("rpm -qa", ['rpm', '-qa']))
        self.add_collectable_item(CommandItem("ifconfig -a", ['/sbin/ifconfig', '-a']))
        self.add_collectable_item(CommandItem('inquiry.py', \
            ['xpyv', INQUIRY_PATH]))
