#!/usr/bin/env xpyv

#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program  
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
# 
#-------------------------------------------------------------------------------------------------   

from os import path, environ
from commands import getoutput
from subprocess import PIPE, Popen

from interfaces import IXIVDiag
from collector.collectable.files import SimpleFileCollectable as FileItem
from collector.collectable.commands import SimpleCommandCollectable as CommandItem
from collector.collectable.directories import SimpleDirectoryCollectable as DirectoryItem

from xpyv import project_root_path

DEFAULTDIR = '/tmp'
HOST_ATTACH_DIR = path.abspath(path.join(project_root_path.find(False)))
HOST_ATTACH_BINDIR = path.join(HOST_ATTACH_DIR, 'bin')
XIV_DEVLIST_PATH = path.join(HOST_ATTACH_BINDIR, 'xiv_devlist')
XIV_FC_ADMIN_PATH = path.join(HOST_ATTACH_BINDIR, 'xiv_fc_admin')
XIV_ISCSI_ADMIN_PATH = path.join(HOST_ATTACH_BINDIR, 'xiv_iscsi_admin')
INQUIRY_PATH = path.join(HOST_ATTACH_DIR, 'lib', 'xiv_diag', 'scripts', 'inquiry.py')

class XIVDiag(IXIVDiag):
    def add_collectables(self):
        self.add_commands()
        self.add_files()
        self.add_directories()

    def add_directories(self):
        self.add_collectable_item(DirectoryItem('/var/adm directory', self.zip_file, "/var/adm"))
        self.add_collectable_item(DirectoryItem('/var/log directory', self.zip_file, "/var/log"))

    def add_files(self):
        self.add_collectable_item(FileItem('scsi_vhci.conf', self.zip_file, '/kernel/drv/scsi_vhci.conf'))
        self.add_collectable_item(FileItem("release", self.zip_file, '/etc/release' ))
        self.add_collectable_item(FileItem('fp.conf', self.zip_file, '/kernel/drv/fp.conf'))

    def add_commands(self):
        self.add_collectable_item(CommandItem("uname", ['uname', '-a']))
        self.add_collectable_item(CommandItem("cfgadm", ['cfgadm', '-al']))
        self.add_collectable_item(CommandItem("find /dev", ['find', '/dev']))
        self.add_collectable_item(CommandItem("Package list", ['pkginfo', '-l']))
        self.add_collectable_item(CommandItem('xiv_devlist' , [XIV_DEVLIST_PATH, '-o', 'all']))
        self.add_collectable_item(CommandItem('xiv_fc_admin -V' , [XIV_FC_ADMIN_PATH, '-V']))
        self.add_collectable_item(CommandItem('xiv_iscsi_admin -V' , [XIV_ISCSI_ADMIN_PATH, '-V']))
        self.add_collectable_item(CommandItem('xiv_fc_admin -L' , [XIV_FC_ADMIN_PATH, '-L']))
        self.add_collectable_item(CommandItem('xiv_fc_admin -P' , [XIV_FC_ADMIN_PATH, '-P']))
        self.add_collectable_item(CommandItem('xiv_iscsi_admin -L' , [XIV_ISCSI_ADMIN_PATH, '-L']))
        self.add_collectable_item(CommandItem('xiv_iscsi_admin -P' , [XIV_ISCSI_ADMIN_PATH, '-P']))
        self.add_collectable_item(CommandItem('inquiry.py', \
            ['xpyv', INQUIRY_PATH]))
