import os
import sys

from os import path

# Constants
MARKER_FILE_NAME = '.projectroot'
DIRTY_BUILD_INFO=[]
VERSION='1.0.7'
XPYV_ENV_PREFIX='XPYV_ORIG_'

# Module globals (Initialized at end of module)
project_root_path = None 
original_environ = None

def get_unmodified_environment():
    """
    Returns the environment without the XPYV modifications
    """
    original_environ = dict()
    originally_empty = list()
    for env_name, env_value in os.environ.iteritems():
        if env_name.startswith(XPYV_ENV_PREFIX):
            original_env_name_offset = len(XPYV_ENV_PREFIX)
            original_env_name = env_name[original_env_name_offset:]
            original_environ[original_env_name] = env_value
            if env_value in ('(none)', '(null)'): 
                originally_empty.append(original_env_name)
        else:
            original_environ[env_name] = env_value
    for env_name in originally_empty:
        if original_environ.has_key(env_name):
            original_environ.pop(env_name)
    return original_environ

class ProjectRootPath(object):
    ERROR_MESSAGE = "Can not find necessary program files (%s not found)" % (MARKER_FILE_NAME,)

    def __init__(self):
        self._project_root_path = None

    def __str__(self):
        return self.find() or ""

    def insert_to_sys_path(self, bin_file=None, die_on_error=True, marker_file_name=MARKER_FILE_NAME,
                                                     error_message=ERROR_MESSAGE):
        if bin_file is None:
            bin_file = self._get_caller2_file_path()
        
        directory = self.find(starting_path=bin_file, marker_file_name=marker_file_name)
        if directory is None:
            if die_on_error:
                print error_message
                sys.exit(1)
            else:
                raise EnvironmentError(error_message)

        sys.path.insert(0, directory)
        return directory

    def find(self, use_cached=True, starting_path=None, marker_file_name=MARKER_FILE_NAME):
        if use_cached and self._project_root_path:
            return self._project_root_path

        if starting_path is None:
            starting_path = self._get_caller2_file_path()
            if starting_path is None:
                return None

        cur_path = path.realpath(path.abspath(starting_path))
        if path.isfile(cur_path):
            cur_path = path.dirname(cur_path)

        last_path = None
        while cur_path != last_path:
            last_path = cur_path
            if path.isfile(path.join(cur_path, marker_file_name)):
                self._project_root_path = cur_path
                return cur_path
            cur_path = path.abspath(path.join(cur_path, '..'))
        return None

    @staticmethod
    def _get_caller2_file_path():
        import inspect
        # Utility method - get the file name of the caller's caller
        caller_file = inspect.stack()[2][1]
        if path.isfile(caller_file):
            return caller_file
        return None

# Initialize globals
project_root_path = ProjectRootPath()
original_environ = get_unmodified_environment()
